@@ -5,7 +5,7 @@ Chisq <- function(df = 1, ncp = 0) new("Chisq", df = df, ncp = ncp)
 Dirac <- function(location = 0) new("Dirac", location = location)
 Exp <- function(rate = 1) new("Exp", rate = rate)
 Fd <- function(df1 = 1, df2 = 1) new("Fd", df1 = df1, df2 = df2)
-Gamma <- function(shape = 1, scale = 1) new("Gamma", shape = shape, scale = scale)
+Gammad <- function(shape = 1, scale = 1) new("Gammad", shape = shape, scale = scale)
 Geom <- function(prob = 0.5) new("Geom", prob = prob)
 Hyper <- function(m = 1, n = 1, k = 1) new("Hyper", m = m, n = n, k = k)
 Logis <- function(location = 0, scale = 1) new("Logis", location = location, scale = scale)
